# mh/__ini__.py
'''
This documentation comes from within the code.

Deffinition of the API
'''

__version__ = '0.0.31'

import mh.mh as mh

EG_VAR2 = mh.EG_VAR
testFunction = mh.testFunction
Mh = mh.Mh

