'''An example of an internal module within the package

Although the intenals are not explicity exposed, they are still available via

    import mhlib
    mhlib.eg.MhEg().runMhEg()

    import mhlib.l2.l2
    mhlib.l2.l2.L2EG_VAR
'''

