'''Documentation for l2.py...'''

import time

L2EG_VAR='efgh'


def L2Test():
    '''L2 test funtion'''
    return 'ok'


class L2Mh (object):
    """class L2Mh documentation"""

    def run(self):
        """No documentation"""
        return 10

    def slow(self):
        """No documentation"""
        t = 5
        time.sleep(t)
        return t

